==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/tr.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Belgeler",
"Can't create document" => "Belge oluşturulamıyor",
"You don't have permission to rename this document" => "Bu belgeyi adlandırmak için izniniz yok.",
"Directory saved successfully." => "Dizin başarıyla kaydedildi.",
"An error occurred while changing directory." => "Dizin değiştirilirken bir hata oluştu.",
"Saved" => "Kaydedildi",
"Format filter server is down or misconfigured" => "Biçim filtre sunucusu kapalı veya hatalı yapılandırılmış",
"Conversion failed. Check log for details." => "Dönüşüm başarısız. Ayrıntılar için günlüğe bakın.",
"document-styles" => "belge-biçemleri",
"document-content" => "belge-içeriği",
"bold" => "kalın",
"italic" => "italik",
"solid" => "düz",
"pt" => "pt",
"Saving..." => "Kaydediliyor...",
"Failed to load documents." => "Belgeler yüklenemedi.",
"No documents were found. Upload or create a document to get started!" => "Hiçbir belge bulunamadı. Lütfen bir belge yükleyin veya oluşturun!",
"No connection to server. Trying to reconnect." => "Sunucuya bağlantı yok. Yeniden bağlanmaya çalışıyor.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Düzenleyici kipinde bu sayfadan ayrılmak, kaydedilmemiş verilere sebep olabilir. Bunun yerine 'Kapat' düğmesi kullanılması önerilir.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Bu belge yüklenemedi. Lütfen harici bir odt düzenleyicisi ile açılıp açılamayacağını denetleyin. Bu ayrıca, yakın zamanda paylaşımın veya dosyanın kaldırılmış olabileceğinden de kaynaklanabilir.",
"Save" => "Kaydet",
"Loading documents..." => "Belgeler yükleniyor...",
"'.' is an invalid file name." => "'.' geçersiz bir dosya adı.",
"File name cannot be empty." => "Dosya adı boş olamaz.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Geçersiz isim, '\\', '/', '<', '>', ':', '\"', '|', '?' ve '*' karakterlerine izin verilmemektedir.",
"Align Left" => "Sola Hizala",
"Alignment" => "Hizalama",
"Align Right" => "Sağa Hizala",
"Annotate" => "Yorum Yap",
"Background" => "Arkaplan",
"Bold" => "Kalın",
"Bottom" => "Alt",
"Cancel" => "İptal",
"Center" => "Orta",
"Clone" => "Kopyala",
"Clone this Style" => "Bu Biçemi Kopyala",
"Close" => "Kapat",
"Color" => "Renk",
"Create" => "Oluştur",
"Decrease Indent" => "Girintiyi Azalt",
"Default Style" => "Öntanımlı Biçem",
"Delete" => "Sil",
"Family" => "Aile",
"Font" => "Yazı Tipi",
"Font Effects" => "Yazı Tipi Efektleri",
"Format" => "Biçim",
"Increase Indent" => "Girintiyi Arttır",
"Insert Image" => "Resim Ekle",
"Invite Members" => "Üye Davet Et",
"Italic" => "Eğik",
"Justified" => "Yaslanmış",
"Justify" => "Yasla",
"Left" => "Sol",
"Loading" => "Yükleniyor",
"Members" => "Üyeler",
"New Name:" => "Yeni İsim:",
"OK" => "Tamam",
"Open" => "Aç",
"Options" => "Seçenekler",
"Paragraph..." => "Paragraf...",
"Paragraph Styles" => "Paragraf Biçemleri",
"Redo" => "Yinele",
"Right" => "Sağ",
"Size" => "Boyut",
"Spacing" => "Boşluklar",
"Strikethrough" => "Üzeri Çizili",
"Style" => "Biçem",
"Text" => "Metin",
"Top" => "Üst",
"Underline" => "Altı Çizili",
"Undo" => "Geri Al",
"Unknown Author" => "Bilinmeyen Yazar",
"Edit" => "Düzenle",
"Share" => "Paylaş",
"guest" => "misafir",
"MS Word support (requires openOffice/libreOffice)" => "MS Word desteği (openOffice/libreOffice gerektirir)",
"Local" => "Yerel",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice bu sunucuda kurulu. İkili dosya yolu, config.php içerisindeki preview_libreoffice_path ile sağlanmaktadır",
"External" => "Harici",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice, bir biçim filtre sunucusu çalıştıran harici sunucuda kurulu",
"Disabled" => "Devre Dışı",
"No MS Word support" => "MS Word desteği yok",
"scheme://domain.tld[:port]" => "scheme://alanadı.tld[:bağl.nokt.]",
"Server URL" => "Sunucu Adresi",
"Apply and test" => "Uygula ve sına",
"New document" => "Yeni belge",
"Upload (max. %s)" => "Yükle (azami: %s)",
"Upload" => "Yükle",
"Save new documents to" => "Yeni belgeleri şuraya kaydet:",
"Wrong password. Please retry." => "Yanlış parola. Lütfen yeniden deneyin.",
"Password" => "Parola",
"Guest %s" => "Misafir %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Bu bağlantının süresi dolmuş veya hiç mevcut olmamış. Lütfen ayrıntılar için paylaşımı yapan kişi ile iletişime geçin.",
"Advanced feature-set" => "Gelişmiş özellik seti",
"(Unstable)" => "(Kararsız)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";

==> owncloud-app-documents-1%3A9.0.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/tr.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Belgeler",
"Can't create document" => "Belge oluşturulamıyor",
"You don't have permission to rename this document" => "Bu belgeyi adlandırmak için izniniz yok.",
"Directory saved successfully." => "Dizin başarıyla kaydedildi.",
"An error occurred while changing directory." => "Dizin değiştirilirken bir hata oluştu.",
"Saved" => "Kaydedildi",
"Format filter server is down or misconfigured" => "Biçim filtre sunucusu kapalı veya hatalı yapılandırılmış",
"Conversion failed. Check log for details." => "Dönüşüm başarısız. Ayrıntılar için günlüğe bakın.",
"Saving..." => "Kaydediliyor...",
"Failed to load documents." => "Belgeler yüklenemedi.",
"No documents were found. Upload or create a document to get started!" => "Hiçbir belge bulunamadı. Lütfen bir belge yükleyin veya oluşturun!",
"No connection to server. Trying to reconnect." => "Sunucuya bağlantı yok. Yeniden bağlanmaya çalışıyor.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Düzenleyici kipinde bu sayfadan ayrılmak, kaydedilmemiş verilere sebep olabilir. Bunun yerine 'Kapat' düğmesi kullanılması önerilir.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Bu belge yüklenemedi. Lütfen harici bir odt düzenleyicisi ile açılıp açılamayacağını denetleyin. Bu ayrıca, yakın zamanda paylaşımın veya dosyanın kaldırılmış olabileceğinden de kaynaklanabilir.",
"Save" => "Kaydet",
"Loading documents..." => "Belgeler yükleniyor...",
"'.' is an invalid file name." => "'.' geçersiz bir dosya adı.",
"File name cannot be empty." => "Dosya adı boş olamaz.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Geçersiz isim, '\\', '/', '<', '>', ':', '\"', '|', '?' ve '*' karakterlerine izin verilmemektedir.",
"Align Left" => "Sola Hizala",
"Alignment" => "Hizalama",
"Align Right" => "Sağa Hizala",
"Annotate" => "Yorum Yap",
"Background" => "Arkaplan",
"Bold" => "Kalın",
"Bottom" => "Alt",
"Cancel" => "İptal",
"Center" => "Orta",
"Clone" => "Kopyala",
"Clone this Style" => "Bu Biçemi Kopyala",
"Close" => "Kapat",
"Color" => "Renk",
"Create" => "Oluştur",
"Decrease Indent" => "Girintiyi Azalt",
"Default Style" => "Öntanımlı Biçem",
"Delete" => "Sil",
"Family" => "Aile",
"Font" => "Yazı Tipi",
"Font Effects" => "Yazı Tipi Efektleri",
"Format" => "Biçim",
"Increase Indent" => "Girintiyi Arttır",
"Insert Image" => "Resim Ekle",
"Invite Members" => "Üye Davet Et",
"Italic" => "Eğik",
"Justified" => "Yaslanmış",
"Justify" => "Yasla",
"Left" => "Sol",
"Loading" => "Yükleniyor",
"Members" => "Üyeler",
"New Name:" => "Yeni İsim:",
"OK" => "Tamam",
"Open" => "Aç",
"Options" => "Seçenekler",
"Paragraph..." => "Paragraf...",
"Paragraph Styles" => "Paragraf Biçemleri",
"Redo" => "Yinele",
"Right" => "Sağ",
"Size" => "Boyut",
"Spacing" => "Boşluklar",
"Strikethrough" => "Üzeri Çizili",
"Style" => "Biçem",
"Text" => "Metin",
"Top" => "Üst",
"Underline" => "Altı Çizili",
"Undo" => "Geri Al",
"Unknown Author" => "Bilinmeyen Yazar",
"Shared" => "Paylaşılan",
"Error" => "Hata",
"Error while sharing" => "Paylaşım sırasında hata",
"Error while unsharing" => "Paylaşım iptal edilirken hata",
"Error while changing permissions" => "İzinleri değiştirirken hata",
"Shared with you and the group {group} by {owner}" => "{owner} tarafından sizinle ve {group} ile paylaştırılmış",
"Shared with you by {owner}" => "{owner} tarafından sizinle paylaşıldı",
"Share with users or groups …" => "Kullanıcı ve gruplarla paylaş...",
"Share with users, groups or remote users …" => "Kullanıcılar, gruplar veya uzak kullanıcılarla paylaş ...",
"Share" => "Paylaş",
"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "kullanıcı@example.com/owncloud şeklinde diğer ownCloud kullanan diğer kullanıcılarla paylaş",
"Share link" => "Paylaşma bağlantısı",
"The public link will expire no later than {days} days after it is created" => "Herkese açık bağlantı, oluşturulduktan en geç {days} gün sonra sona erecek",
"Link" => "Bağlantı",
"Password protect" => "Parola koruması",
"Password" => "Parola",
"Choose a password for the public link" => "Herkese açık bağlantı için bir parola seçin",
"Allow editing" => "Düzenlemeye izin ver",
"Email link to person" => "Bağlantıyı e-posta ile gönder",
"Send" => "Gönder",
"Set expiration date" => "Son kullanma tarihini ayarla",
"Expiration" => "Bitiş",
"Expiration date" => "Son kullanım tarihi",
"An error occured. Please try again" => "Bir hata oluştu. Lütfen yeniden deneyin",
"Adding user..." => "Kullanıcı ekleniyor...",
"group" => "grup",
"remote" => "uzak",
"Resharing is not allowed" => "Tekrar paylaşmaya izin verilmiyor",
"Shared in {item} with {user}" => "{item} içinde {user} ile paylaşılanlar",
"Unshare" => "Paylaşmayı Kaldır",
"notify by email" => "e-posta ile bildir",
"can share" => "paylaşabilir",
"can edit" => "düzenleyebilir",
"access control" => "erişim kontrolü",
"create" => "oluştur",
"change" => "değiştir",
"delete" => "sil",
"Password protected" => "Parola korumalı",
"Error unsetting expiration date" => "Son kullanma tarihi kaldırma hatası",
"Error setting expiration date" => "Son kullanma tarihi ayarlama hatası",
"Sending ..." => "Gönderiliyor...",
"Email sent" => "E-posta gönderildi",
"Warning" => "Uyarı",
"Edit" => "Düzenle",
"guest" => "misafir",
"MS Word support (requires openOffice/libreOffice)" => "MS Word desteği (openOffice/libreOffice gerektirir)",
"Local" => "Yerel",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice bu sunucuda kurulu. İkili dosya yolu, config.php içerisindeki preview_libreoffice_path ile sağlanmaktadır",
"External" => "Harici",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice, bir biçim filtre sunucusu çalıştıran harici sunucuda kurulu",
"Disabled" => "Devre Dışı",
"No MS Word support" => "MS Word desteği yok",
"scheme://domain.tld[:port]" => "scheme://alanadı.tld[:bağl.nokt.]",
"Server URL" => "Sunucu Adresi",
"Apply and test" => "Uygula ve sına",
"New document" => "Yeni belge",
"Upload (max. %s)" => "Yükle (azami: %s)",
"Upload" => "Yükle",
"Save new documents to" => "Yeni belgeleri şuraya kaydet:",
"Wrong password. Please retry." => "Yanlış parola. Lütfen yeniden deneyin.",
"Guest %s" => "Misafir %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Bu bağlantının süresi dolmuş veya hiç mevcut olmamış. Lütfen ayrıntılar için paylaşımı yapan kişi ile iletişime geçin.",
"Advanced feature-set" => "Gelişmiş özellik seti",
"(Unstable)" => "(Kararsız)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
